/* _dict.cc 03/03/1998 00.39.00 */
/* menuedit.cc 12/12/1999 22.10.50 */
/* show.cc 12/12/1999 22.10.50 */
/* usermenu.cc 28/08/2000 18.15.10 */
PUBLIC MODULE_usermenu::MODULE_usermenu (void);
PUBLIC void MODULE_usermenu::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_usermenu::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_usermenu::dohtml (const char *key);
PUBLIC void MODULE_usermenu::usage (SSTRINGS&tb);
PUBLIC int MODULE_usermenu::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_usermenu::message (const char *msg,
	 int ,
	 const char *[]);
